==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/search/all_68.js <==
var searchData=
[
  ['h',['h',['../structtriangle.html#a82dbd6f31285b6c60e4c035417c6716b',1,'triangle::h()'],['../structcsa.html#acba79cb4f4eb19929c067cf52e145131',1,'csa::h()'],['../structplplot_1_1__N10.html#ae099434248d49c9374af650a07cf4b10',1,'plplot::_N10::h()'],['../structPLControlPt.html#a73674db8c26cba9caffc05e49c55e6cd',1,'PLControlPt::h()']]],
  ['hack',['hack',['../structPLStream.html#ac98930296aded0072e2beaeb4c8dcdbd',1,'PLStream']]],
  ['handler',['handler',['../structPLOptionTable.html#ab6dca4025110f8770f16f57016402247',1,'PLOptionTable']]],
  ['has_5fstring_5flength',['has_string_length',['../structPLStream.html#abb61b1a584d5cbce8a389a7df736cd9b',1,'PLStream']]],
  ['hasalpha',['hasAlpha',['../aqt_8c.html#ae34bdcef7e730aa1e350245620013128',1,'aqt.c']]],
  ['hascoeffs',['hascoeffs',['../structtriangle.html#a76fa4a762d76a9c09436bbaca8153dbf',1,'triangle']]],
  ['hash',['hash',['../structhashtable.html#ada2423b92f4c35ba085f0657d13d9d89',1,'hashtable']]],
  ['hash_2ec',['hash.c',['../hash_8c.html',1,'']]],
  ['hash_2eh',['hash.h',['../hash_8h.html',1,'']]],
  ['hashtable',['hashtable',['../structhashtable.html',1,'hashtable'],['../hash_8h.html#a70220a04ca914ec91d54260b4608234a',1,'hashtable():&#160;hash.h']]],
  ['hasshear',['hasShear',['../aqt_8c.html#a05494dfe54e9cdc2aef92f11d20d8f57',1,'aqt.c']]],
  ['have_5fcmath',['HAVE_CMATH',['../plplot__config_8h.html#a5ebdfdabf36598943dc9faa5699a1ba5',1,'plplot_config.h']]],
  ['have_5fdirent_5fh',['HAVE_DIRENT_H',['../plplot__config_8h.html#af9fbe15f58004c91c2d8b1fbaf91c1a3',1,'plplot_config.h']]],
  ['have_5fitcl',['HAVE_ITCL',['../plplot__config_8h.html#a9674fe1f44f8ca89965d05a4d8cc6624',1,'plplot_config.h']]],
  ['have_5fitcldecls_5fh',['HAVE_ITCLDECLS_H',['../plplot__config_8h.html#a3d1f3e14c486a4fa6818a2944ad2cda8',1,'plplot_config.h']]],
  ['have_5fitk',['HAVE_ITK',['../plplot__config_8h.html#a9b44549db2bdd6196f3f8a2dae208042',1,'plplot_config.h']]],
  ['have_5fpango',['HAVE_PANGO',['../plplot__config_8h.html#ab84f2ca0bf34a463538b4e35fef25afb',1,'plplot_config.h']]],
  ['have_5fpopen',['HAVE_POPEN',['../plplot__config_8h.html#a42f2de81cc9398f23045b483488d082d',1,'plplot_config.h']]],
  ['have_5fshapelib',['HAVE_SHAPELIB',['../plplot__config_8h.html#a38f0d4e942c7de1a1b1399f7745e81ac',1,'plplot_config.h']]],
  ['have_5fsys_5fwait_5fh',['HAVE_SYS_WAIT_H',['../plplot__config_8h.html#af249315f5939884ce5b4585ca81a1e39',1,'plplot_config.h']]],
  ['have_5ftermios_5fh',['HAVE_TERMIOS_H',['../plplot__config_8h.html#a55e62c01f41f9c5850dfce5f89a6bb98',1,'plplot_config.h']]],
  ['head',['head',['../tclMatrix_8c.html#ae1859da70930176a2e2e760d5fd586dd',1,'tclMatrix.c']]],
  ['header',['header',['../deltaT-gen_8c.html#a2d5bf705d4e4df438762a5c261d6e530',1,'header():&#160;deltaT-gen.c'],['../tai-utc-gen_8c.html#a2d5bf705d4e4df438762a5c261d6e530',1,'header():&#160;tai-utc-gen.c']]],
  ['height',['height',['../classwxPLDevBase.html#aea5e1f836090fa9329ecafc1e61e953e',1,'wxPLDevBase::height()'],['../structplplot_1_1__N4.html#af0fcd17063b1211df598d89ab23d8361',1,'plplot::_N4::height()'],['../structPlFrame.html#a753f618be981a067497386eaba0689de',1,'PlFrame::height()'],['../structTkDev.html#a93af910ff8947e3db175cd7a00f36f9d',1,'TkDev::height()'],['../structPlPlotter.html#a91881b075adcf699c51d4457497e1136',1,'PlPlotter::height()'],['../structTkwDev.html#abebe7feeebbabbd8fbf9f13f9e3ec748',1,'TkwDev::height()'],['../structGcwPLdev.html#ad5ea3d3f2fca3485462c59bb25a702b9',1,'GcwPLdev::height()'],['../structPLDisplay.html#abfc69cbabc752b85010ad60e8cd2c1d1',1,'PLDisplay::height()'],['../structXwDev.html#a945f683c2d2fcb353d8a2484cc79338c',1,'XwDev::height()']]],
  ['help',['Help',['../plargs_8c.html#a80a32bba36fcac6f698e1036d5291c31',1,'plargs.c']]],
  ['help_5ftext',['help_text',['../classoctave__swig__type.html#a085e9c2cfe7b13cb219b79903de0524c',1,'octave_swig_type']]],
  ['hershey',['Hershey',['../structHershey__to__Unicode__table.html#a7747e2b55ce7b3f926422674bf7a98e2',1,'Hershey_to_Unicode_table']]],
  ['hershey2unicode',['hershey2unicode',['../plsym_8c.html#a36bdc3964d3b4b63647e5fcf363cd494',1,'plsym.c']]],
  ['hershey_5fto_5funicode_5flookup_5ftable',['hershey_to_unicode_lookup_table',['../plplotP_8h.html#a018bc4e28f0a17e8e928a7815f866b43',1,'hershey_to_unicode_lookup_table():&#160;plhershey-unicode.h'],['../plhershey-unicode_8h.html#a1aa0c83f54d4d4823a76ab89ac80ce16',1,'hershey_to_unicode_lookup_table():&#160;plhershey-unicode.h']]],
  ['hershey_5fto_5funicode_5ftable',['Hershey_to_Unicode_table',['../structHershey__to__Unicode__table.html',1,'']]],
  ['high_5fcap_5fcolor',['high_cap_color',['../plplot__octave_8h.html#abb0ae89470f54dd69ea180fa9a5a4c71',1,'plplot_octave.h']]],
  ['hinstlib',['hinstLib',['../struct____dlhandle.html#ad612da9abe95210282423ac7bd98bfa4',1,'__dlhandle']]],
  ['hist',['hist',['../classplstream.html#a04852ccad48362688647600b24e01cd9',1,'plstream::hist()'],['../classplplot_1_1core_1_1PLStream.html#a46e6f2b81864c2d95bc5a2b88c9e5288',1,'plplot.core.PLStream.hist()']]],
  ['hlp_5fmsg',['hlp_msg',['../structDrvOpt.html#a57e8cd1b98d06fefc2264e957e1c524e',1,'DrvOpt']]],
  ['hlsrgb',['hlsrgb',['../classplstream.html#ab4be85ad0d45692332ab2bb12dc75dc6',1,'plstream::hlsrgb()'],['../classplplot_1_1core_1_1PLStream.html#a7345b2a3dd9cd6cb6a8833a884896971',1,'plplot.core.PLStream.hlsrgb()']]],
  ['hpgl_2ec',['hpgl.c',['../hpgl_8c.html',1,'']]],
  ['hrshsym',['hrshsym',['../gcw_8c.html#aa20a33fff795f0a9b965f3a914eca6b2',1,'gcw.c']]],
  ['ht_5fbucket',['ht_bucket',['../structht__bucket.html',1,'ht_bucket'],['../hash_8c.html#a5699b37655a24efcc78ca3fdfba6618a',1,'ht_bucket():&#160;hash.c']]],
  ['ht_5fcreate',['ht_create',['../hash_8c.html#abaf48efb76bbea344bf89d3a00f69d72',1,'ht_create(int size, ht_keycp cp, ht_keyeq eq, ht_key2hash hash):&#160;hash.c'],['../hash_8h.html#abaf48efb76bbea344bf89d3a00f69d72',1,'ht_create(int size, ht_keycp cp, ht_keyeq eq, ht_key2hash hash):&#160;hash.c']]],
  ['ht_5fcreate_5fd1',['ht_create_d1',['../hash_8c.html#a897c72d0ee917646439d1b49d917ec92',1,'ht_create_d1(int size):&#160;hash.c'],['../hash_8h.html#a897c72d0ee917646439d1b49d917ec92',1,'ht_create_d1(int size):&#160;hash.c']]],
  ['ht_5fcreate_5fd2',['ht_create_d2',['../hash_8c.html#a5915b44b199695292bc796e4d6ec2184',1,'ht_create_d2(int size):&#160;hash.c'],['../hash_8h.html#a5915b44b199695292bc796e4d6ec2184',1,'ht_create_d2(int size):&#160;hash.c']]],
  ['ht_5fcreate_5fstr',['ht_create_str',['../hash_8c.html#abb922122caa616674000f01ffa89b3c8',1,'ht_create_str(int size):&#160;hash.c'],['../hash_8h.html#abb922122caa616674000f01ffa89b3c8',1,'ht_create_str(int size):&#160;hash.c']]],
  ['ht_5fdata',['ht_data',['../structnnhpi.html#a126ee669cab3462cbc52b7a329beaba1',1,'nnhpi']]],
  ['ht_5fdelete',['ht_delete',['../hash_8c.html#a392643feb6b3e9120d5b49b073961362',1,'ht_delete(hashtable *table, void *key):&#160;hash.c'],['../hash_8h.html#a392643feb6b3e9120d5b49b073961362',1,'ht_delete(hashtable *table, void *key):&#160;hash.c']]],
  ['ht_5fdestroy',['ht_destroy',['../hash_8c.html#a705f1079a9ea4b592cae0d673525c495',1,'ht_destroy(hashtable *table):&#160;hash.c'],['../hash_8h.html#a705f1079a9ea4b592cae0d673525c495',1,'ht_destroy(hashtable *table):&#160;hash.c']]],
  ['ht_5ffind',['ht_find',['../hash_8c.html#a9e11dc665562bec94ceb31b3036a5b2d',1,'ht_find(hashtable *table, void *key):&#160;hash.c'],['../hash_8h.html#a9e11dc665562bec94ceb31b3036a5b2d',1,'ht_find(hashtable *table, void *key):&#160;hash.c']]],
  ['ht_5finsert',['ht_insert',['../hash_8c.html#a0f56f940c878c3339c51b037a8edfd7a',1,'ht_insert(hashtable *table, void *key, void *data):&#160;hash.c'],['../hash_8h.html#a0f56f940c878c3339c51b037a8edfd7a',1,'ht_insert(hashtable *table, void *key, void *data):&#160;hash.c']]],
  ['ht_5fkey2hash',['ht_key2hash',['../hash_8h.html#ab09765dc348f0c924c008c9db56992f7',1,'hash.h']]],
  ['ht_5fkeycp',['ht_keycp',['../hash_8h.html#ac126335e0c499a0b69a70c3d0ccc1223',1,'hash.h']]],
  ['ht_5fkeyeq',['ht_keyeq',['../hash_8h.html#a8b7f7326bc138e8d91d0de5bbacd3f36',1,'hash.h']]],
  ['ht_5fprocess',['ht_process',['../hash_8c.html#ac529347b3cad9a069f20048682f3b735',1,'ht_process(hashtable *table, void(*func)(void *)):&#160;hash.c'],['../hash_8h.html#ac529347b3cad9a069f20048682f3b735',1,'ht_process(hashtable *table, void(*func)(void *)):&#160;hash.c']]],
  ['ht_5fweights',['ht_weights',['../structnnhpi.html#ac51966e4ed100e61f47fbf3887a19a7b',1,'nnhpi']]],
  ['huge_5fval',['HUGE_VAL',['../plplotP_8h.html#af2164b2db92d8a0ed3838ad5c28db971',1,'plplotP.h']]]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/search/all_68.js <==
var searchData=
[
  ['h',['h',['../structtriangle.html#a82dbd6f31285b6c60e4c035417c6716b',1,'triangle::h()'],['../structcsa.html#acba79cb4f4eb19929c067cf52e145131',1,'csa::h()'],['../structplplot_1_1__N10.html#ae099434248d49c9374af650a07cf4b10',1,'plplot::_N10::h()'],['../structPLControlPt.html#a73674db8c26cba9caffc05e49c55e6cd',1,'PLControlPt::h()']]],
  ['hack',['hack',['../structPLStream.html#ac98930296aded0072e2beaeb4c8dcdbd',1,'PLStream']]],
  ['handler',['handler',['../structPLOptionTable.html#ad5c9d7750a254ebc521db666d0ecc6fd',1,'PLOptionTable']]],
  ['has_5fstring_5flength',['has_string_length',['../structPLStream.html#abb61b1a584d5cbce8a389a7df736cd9b',1,'PLStream']]],
  ['hasalpha',['hasAlpha',['../aqt_8c.html#ae34bdcef7e730aa1e350245620013128',1,'aqt.c']]],
  ['hascoeffs',['hascoeffs',['../structtriangle.html#a76fa4a762d76a9c09436bbaca8153dbf',1,'triangle']]],
  ['hash',['hash',['../structhashtable.html#ada2423b92f4c35ba085f0657d13d9d89',1,'hashtable']]],
  ['hash_2ec',['hash.c',['../hash_8c.html',1,'']]],
  ['hash_2eh',['hash.h',['../hash_8h.html',1,'']]],
  ['hashtable',['hashtable',['../structhashtable.html',1,'hashtable'],['../hash_8h.html#a70220a04ca914ec91d54260b4608234a',1,'hashtable():&#160;hash.h']]],
  ['hasshear',['hasShear',['../aqt_8c.html#a05494dfe54e9cdc2aef92f11d20d8f57',1,'aqt.c']]],
  ['have_5fcmath',['HAVE_CMATH',['../plplot__config_8h.html#a5ebdfdabf36598943dc9faa5699a1ba5',1,'plplot_config.h']]],
  ['have_5fdirent_5fh',['HAVE_DIRENT_H',['../plplot__config_8h.html#af9fbe15f58004c91c2d8b1fbaf91c1a3',1,'plplot_config.h']]],
  ['have_5fitcl',['HAVE_ITCL',['../plplot__config_8h.html#a9674fe1f44f8ca89965d05a4d8cc6624',1,'plplot_config.h']]],
  ['have_5fitcldecls_5fh',['HAVE_ITCLDECLS_H',['../plplot__config_8h.html#a3d1f3e14c486a4fa6818a2944ad2cda8',1,'plplot_config.h']]],
  ['have_5fitk',['HAVE_ITK',['../plplot__config_8h.html#a9b44549db2bdd6196f3f8a2dae208042',1,'plplot_config.h']]],
  ['have_5fpango',['HAVE_PANGO',['../plplot__config_8h.html#ab84f2ca0bf34a463538b4e35fef25afb',1,'plplot_config.h']]],
  ['have_5fpopen',['HAVE_POPEN',['../plplot__config_8h.html#a42f2de81cc9398f23045b483488d082d',1,'plplot_config.h']]],
  ['have_5fshapelib',['HAVE_SHAPELIB',['../plplot__config_8h.html#a38f0d4e942c7de1a1b1399f7745e81ac',1,'plplot_config.h']]],
  ['have_5fsys_5fwait_5fh',['HAVE_SYS_WAIT_H',['../plplot__config_8h.html#af249315f5939884ce5b4585ca81a1e39',1,'plplot_config.h']]],
  ['have_5ftermios_5fh',['HAVE_TERMIOS_H',['../plplot__config_8h.html#a55e62c01f41f9c5850dfce5f89a6bb98',1,'plplot_config.h']]],
  ['head',['head',['../tclMatrix_8c.html#ae1859da70930176a2e2e760d5fd586dd',1,'tclMatrix.c']]],
  ['header',['header',['../deltaT-gen_8c.html#a2d5bf705d4e4df438762a5c261d6e530',1,'header():&#160;deltaT-gen.c'],['../tai-utc-gen_8c.html#a2d5bf705d4e4df438762a5c261d6e530',1,'header():&#160;tai-utc-gen.c']]],
  ['height',['height',['../structTextSizeInfo.html#ae16b2b6b80bf45ef08e0baf075186960',1,'TextSizeInfo::height()'],['../structplplot_1_1__N4.html#af0fcd17063b1211df598d89ab23d8361',1,'plplot::_N4::height()'],['../structPlFrame.html#a753f618be981a067497386eaba0689de',1,'PlFrame::height()'],['../structTkDev.html#a93af910ff8947e3db175cd7a00f36f9d',1,'TkDev::height()'],['../structPlPlotter.html#a91881b075adcf699c51d4457497e1136',1,'PlPlotter::height()'],['../structTkwDev.html#abebe7feeebbabbd8fbf9f13f9e3ec748',1,'TkwDev::height()'],['../structPLDisplay.html#abfc69cbabc752b85010ad60e8cd2c1d1',1,'PLDisplay::height()'],['../structXwDev.html#a945f683c2d2fcb353d8a2484cc79338c',1,'XwDev::height()']]],
  ['help',['Help',['../plargs_8c.html#a80a32bba36fcac6f698e1036d5291c31',1,'plargs.c']]],
  ['help_5ftext',['help_text',['../classoctave__swig__type.html#a085e9c2cfe7b13cb219b79903de0524c',1,'octave_swig_type']]],
  ['hershey',['Hershey',['../structHershey__to__Unicode__table.html#a7747e2b55ce7b3f926422674bf7a98e2',1,'Hershey_to_Unicode_table']]],
  ['hershey2unicode',['hershey2unicode',['../plsym_8c.html#a36bdc3964d3b4b63647e5fcf363cd494',1,'plsym.c']]],
  ['hershey_5fto_5funicode_5flookup_5ftable',['hershey_to_unicode_lookup_table',['../plplotP_8h.html#a018bc4e28f0a17e8e928a7815f866b43',1,'hershey_to_unicode_lookup_table():&#160;plhershey-unicode.h'],['../plhershey-unicode_8h.html#a1aa0c83f54d4d4823a76ab89ac80ce16',1,'hershey_to_unicode_lookup_table():&#160;plhershey-unicode.h']]],
  ['hershey_5fto_5funicode_5ftable',['Hershey_to_Unicode_table',['../structHershey__to__Unicode__table.html',1,'']]],
  ['hinstlib',['hinstLib',['../struct____dlhandle.html#ad612da9abe95210282423ac7bd98bfa4',1,'__dlhandle']]],
  ['hist',['hist',['../classplstream.html#a04852ccad48362688647600b24e01cd9',1,'plstream::hist()'],['../classplplot_1_1core_1_1PLStream.html#a46e6f2b81864c2d95bc5a2b88c9e5288',1,'plplot.core.PLStream.hist()']]],
  ['hlp_5fmsg',['hlp_msg',['../structDrvOpt.html#a57e8cd1b98d06fefc2264e957e1c524e',1,'DrvOpt']]],
  ['hlsrgb',['hlsrgb',['../classplstream.html#ab4be85ad0d45692332ab2bb12dc75dc6',1,'plstream::hlsrgb()'],['../classplplot_1_1core_1_1PLStream.html#a7345b2a3dd9cd6cb6a8833a884896971',1,'plplot.core.PLStream.hlsrgb()']]],
  ['ht_5fbucket',['ht_bucket',['../structht__bucket.html',1,'ht_bucket'],['../hash_8c.html#a5699b37655a24efcc78ca3fdfba6618a',1,'ht_bucket():&#160;hash.c']]],
  ['ht_5fcreate',['ht_create',['../hash_8c.html#abaf48efb76bbea344bf89d3a00f69d72',1,'ht_create(int size, ht_keycp cp, ht_keyeq eq, ht_key2hash hash):&#160;hash.c'],['../hash_8h.html#abaf48efb76bbea344bf89d3a00f69d72',1,'ht_create(int size, ht_keycp cp, ht_keyeq eq, ht_key2hash hash):&#160;hash.c']]],
  ['ht_5fcreate_5fd1',['ht_create_d1',['../hash_8c.html#a897c72d0ee917646439d1b49d917ec92',1,'ht_create_d1(int size):&#160;hash.c'],['../hash_8h.html#a897c72d0ee917646439d1b49d917ec92',1,'ht_create_d1(int size):&#160;hash.c']]],
  ['ht_5fcreate_5fd2',['ht_create_d2',['../hash_8c.html#a5915b44b199695292bc796e4d6ec2184',1,'ht_create_d2(int size):&#160;hash.c'],['../hash_8h.html#a5915b44b199695292bc796e4d6ec2184',1,'ht_create_d2(int size):&#160;hash.c']]],
  ['ht_5fcreate_5fstr',['ht_create_str',['../hash_8c.html#abb922122caa616674000f01ffa89b3c8',1,'ht_create_str(int size):&#160;hash.c'],['../hash_8h.html#abb922122caa616674000f01ffa89b3c8',1,'ht_create_str(int size):&#160;hash.c']]],
  ['ht_5fdata',['ht_data',['../structnnhpi.html#a126ee669cab3462cbc52b7a329beaba1',1,'nnhpi']]],
  ['ht_5fdelete',['ht_delete',['../hash_8c.html#a392643feb6b3e9120d5b49b073961362',1,'ht_delete(hashtable *table, void *key):&#160;hash.c'],['../hash_8h.html#a392643feb6b3e9120d5b49b073961362',1,'ht_delete(hashtable *table, void *key):&#160;hash.c']]],
  ['ht_5fdestroy',['ht_destroy',['../hash_8c.html#a705f1079a9ea4b592cae0d673525c495',1,'ht_destroy(hashtable *table):&#160;hash.c'],['../hash_8h.html#a705f1079a9ea4b592cae0d673525c495',1,'ht_destroy(hashtable *table):&#160;hash.c']]],
  ['ht_5ffind',['ht_find',['../hash_8c.html#a9e11dc665562bec94ceb31b3036a5b2d',1,'ht_find(hashtable *table, void *key):&#160;hash.c'],['../hash_8h.html#a9e11dc665562bec94ceb31b3036a5b2d',1,'ht_find(hashtable *table, void *key):&#160;hash.c']]],
  ['ht_5finsert',['ht_insert',['../hash_8c.html#a0f56f940c878c3339c51b037a8edfd7a',1,'ht_insert(hashtable *table, void *key, void *data):&#160;hash.c'],['../hash_8h.html#a0f56f940c878c3339c51b037a8edfd7a',1,'ht_insert(hashtable *table, void *key, void *data):&#160;hash.c']]],
  ['ht_5fkey2hash',['ht_key2hash',['../hash_8h.html#ab09765dc348f0c924c008c9db56992f7',1,'hash.h']]],
  ['ht_5fkeycp',['ht_keycp',['../hash_8h.html#ac126335e0c499a0b69a70c3d0ccc1223',1,'hash.h']]],
  ['ht_5fkeyeq',['ht_keyeq',['../hash_8h.html#a8b7f7326bc138e8d91d0de5bbacd3f36',1,'hash.h']]],
  ['ht_5fprocess',['ht_process',['../hash_8c.html#ac529347b3cad9a069f20048682f3b735',1,'ht_process(hashtable *table, void(*func)(void *)):&#160;hash.c'],['../hash_8h.html#ac529347b3cad9a069f20048682f3b735',1,'ht_process(hashtable *table, void(*func)(void *)):&#160;hash.c']]],
  ['ht_5fweights',['ht_weights',['../structnnhpi.html#ac51966e4ed100e61f47fbf3887a19a7b',1,'nnhpi']]],
  ['huge_5fval',['HUGE_VAL',['../plplotP_8h.html#af2164b2db92d8a0ed3838ad5c28db971',1,'plplotP.h']]]
];
